<?php

namespace FiloBlu\Esb\Model\Producer;

use FiloBlu\Esb\Api\Data\MessageInterface;
use FiloBlu\Esb\Api\Data\StatusInterface;
use FiloBlu\Esb\Core\Extractor\ObjectTypeFromMessage;
use Magento\Framework\DataObject;
use Magento\Rma\Api\Data\RmaInterface;

/**
 * Class CreditMemoSaveAfterProducer
 * @package FiloBlu\Esb\Model\Producer
 */
class RmaSaveAfterProducer extends AbstractRmaProducer
{

    /**
     * @inheritDoc
     */
    public function produce(RmaInterface $rma = null): MessageInterface
    {
        $a=1;
        /** @var MessageInterface $message */
        $message = $this->getMessageFactory()->create();

        if ($rma === null || !$this->isConditionSatisfied($this->prepareDataForEvaluation($rma))) {
            $this->getStatus()
                ->setCode(StatusInterface::SKIPPED)
                ->setOutputData($rma === null ? 'Rma was null' : 'Condition was not satisfied');
            return $message;
        }

        $parameters = $this->getConfiguration()->getParameters();

        if ($rma !== null && $parameters->hasData(self::PAYLOAD_KEY)) {
            $template = $parameters->getData(self::PAYLOAD_KEY);
            $this->messageFiller->fill($message, $this->getDataForFiller($rma), $template);
        }

        $message->getPayload()->addData([
            ObjectTypeFromMessage::OBJECT_TYPE_PATH => $this->getObjectTypeDescriptor()->getTypeCode(),
            ObjectTypeFromMessage::OBJECT_ID_PATH => $rma->getEntityId()
        ]);

        $this->getStatus()->setCode(StatusInterface::SUCCESS);

        return $message;
    }

    /**
     * @param RmaInterface $rma
     * @return DataObject
     */
    protected function prepareDataForEvaluation(RmaInterface $rma = null): DataObject
    {
        /** @var DataObject $dataToEvaluate */
        $dataToEvaluate = $this->dataObjectFactory->create();

        if ($rma === null) {
            return $dataToEvaluate;
        }

        $dataToEvaluate->setData('data', $rma);
        $dataToEvaluate->setData('origdata', $rma->getOrigData() ?: $this->dataObjectFactory->create());
        return $dataToEvaluate;
    }

    /**
     * @param RmaInterface $rma
     * @return mixed
     */
    protected function getDataForFiller(RmaInterface $rma)
    {
        return $this->dataObjectFactory->create(
            [
                'data' => [
                    'data' => $rma,
                    'origdata' => $rma->getOrigData() ?: $this->dataObjectFactory->create()
                ]
            ]
        );
    }

    /**
     * @inheritDoc
     */
    public function getName(): string
    {
        return 'Rma Save After Producer';
    }

    /**
     * @inheritDoc
     */
    public function getUniqueName(): string
    {
        return 'FiloBlu_Esb::rma_save_after';
    }
}
